@@ -131,6 +131,36 @@ BIGINT;
 UNIX_MILLIS(CAST('2008-12-25 15:30:00+00' AS TIMESTAMP));
 BIGINT;
 
+KURTOSIS(tbl.double_col);
+DOUBLE;
+
+KURTOSIS(tbl.int_col);
+DOUBLE;
+
+LENGTH(tbl.str_col);
+INT;
+
+LENGTH(tbl.bin_col);
+INT;
+
+DAYNAME(tbl.date_col);
+VARCHAR;
+
+CBRT(tbl.int_col);
+DOUBLE;
+
+CBRT(tbl.double_col);
+DOUBLE;
+
+ISINF(tbl.float_col);
+BOOLEAN;
+
+ISNAN(tbl.float_col);
+BOOLEAN;
+
+CURRENT_CATALOG();
+VARCHAR;
+
 # dialect: snowflake
 TO_BINARY('test');
 BINARY;
@@ -343,6 +373,14 @@ STRING;
 UNIX_TIMESTAMP();
 BIGINT;
 
+# dialect: hive, spark2, spark, databricks
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ACOS(tbl.double_col);
+DOUBLE;
+
 # dialect: spark2, spark, databricks
 ATAN2(tbl.int_col, tbl.int_col);
 DOUBLE;
@@ -355,6 +393,38 @@ DOUBLE;
 ATAN2(tbl.double_col, tbl.int_col);
 DOUBLE;
 
+# dialect: spark, databricks
+ACOSH(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ACOSH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COSH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COSH(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SINH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SINH(tbl.int_col);
+DOUBLE;
+
 # dialect: hive, spark2, spark, databricks
 TANH(tbl.double_col);
 DOUBLE;
@@ -363,6 +433,201 @@ DOUBLE;
 TANH(tbl.int_col);
 DOUBLE;
 
+# dialect: spark, databricks
+TO_BINARY(tbl.str_col, tbl.str_col);
+BINARY;
+
+# dialect: spark, databricks
+TO_BINARY(tbl.int_col, tbl.str_col);
+BINARY;
+
+# dialect: spark, databricks
+TO_BINARY(tbl.double_col, tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+SHA(tbl.str_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SHA1(tbl.str_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SHA2(tbl.str_col, tbl.int_col);
+VARCHAR;
+
+# dialect: hive, spark2, spark, databricks
+SPACE(tbl.int_col);
+VARCHAR;
+
+# dialect: spark2, spark, databricks
+RANDN();
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+BIT_LENGTH(tbl.str_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ASINH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ASINH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: spark, databricks
+ATANH(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+SEC(tbl.int_col);
+DOUBLE;
+
+# dialect: spark, databricks
+SEC(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CORR(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CORR(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CBRT(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CBRT(tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_CATALOG();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_DATABASE();
+STRING;
+
+# dialect: spark, databricks
+DATE_FROM_UNIX_DATE(tbl.int_col);
+DATE;
+
+# dialect: hive, spark2, spark, databricks
+MONTHS_BETWEEN(tbl.timestamp_col, tbl.timestamp_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+MONTHS_BETWEEN(tbl.timestamp_col, tbl.timestamp_col, tbl.bool_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+MONTH(tbl.date_col);
+INT;
+
+# dialect: spark, databricks
+MONTHNAME(tbl.date_col);
+STRING;
+
+# dialect: hive, spark, databricks
+CURRENT_SCHEMA();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+CURRENT_USER();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+UNHEX(tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+HEX(tbl.str_col);
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+HEX(tbl.int_col);
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+SOUNDEX(tbl.str_col);
+STRING;
+
+# dialect: spark, databricks
+SESSION_USER();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+FACTORIAL(tbl.int_col);
+BIGINT;
+
+# dialect: spark, databricks
+ARRAY_SIZE(tbl.array_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+QUARTER(tbl.date_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+SECOND(tbl.timestamp_col);
+INT;
+
+# dialect: hive, spark2, spark, databricks
+MD5(tbl.str_col);
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+HOUR(tbl.timestamp_col);
+INT;
 
 --------------------------------------
 -- BigQuery
@@ -516,6 +781,30 @@ TIMESTAMPTZ;
 TIMESTAMP(tbl.str_col);
 TIMESTAMPTZ;
 
+# dialect: bigquery
+SAFE.PARSE_DATE('%Y-%m-%d', '2024-01-15');
+DATE;
+
+# dialect: bigquery
+PARSE_DATE('%Y-%m-%d', '2024-01-15');
+DATE;
+
+# dialect: bigquery
+SAFE.PARSE_DATETIME('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+DATETIME;
+
+# dialect: bigquery
+SAFE.PARSE_TIME('%H:%M:%S', '10:30:00');
+TIME;
+
+# dialect: bigquery
+SAFE.PARSE_TIMESTAMP('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+TIMESTAMPTZ;
+
+# dialect: bigquery
+PARSE_TIMESTAMP('%Y-%m-%d %H:%M:%S', '2024-01-15 10:30:00');
+TIMESTAMPTZ;
+
 # dialect: bigquery
 CONCAT(tbl.str_col, tbl.str_col);
 STRING;
@@ -1152,6 +1441,10 @@ STRING;
 NET.HOST('http://example.com');
 STRING;
 
+# dialect: bigquery
+NET.REG_DOMAIN('http://example.com');
+STRING;
+
 # dialect: bigquery
 PERCENTILE_CONT(CAST(1 AS NUMERIC), CAST(1 AS NUMERIC)) OVER (ORDER BY 1);
 NUMERIC;
@@ -1760,6 +2053,66 @@ STRING;
 r'a';
 STRING;
 
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 5 DAY);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 2 WEEK);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 3 MONTH);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 1 QUARTER);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(DATE '2008-12-25', INTERVAL 2 YEAR);
+DATE;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 5 DAY);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 2 HOUR);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(TIMESTAMP '2008-12-25 15:30:00', INTERVAL 30 MINUTE);
+TIMESTAMP;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 5 DAY);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 WEEK);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 3 MONTH);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 1 QUARTER);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 YEAR);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 2 HOUR);
+DATETIME;
+
+# dialect: bigquery
+DATE_ADD(DATETIME '2008-12-25 15:30:00', INTERVAL 30 MINUTE);
+DATETIME;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
@@ -1792,6 +2145,10 @@ ARRAY;
 ARRAY_CONSTRUCT_COMPACT(1, null, 2);
 ARRAY;
 
+# dialect: snowflake
+ARRAY_COMPACT([1, null, 2]);
+ARRAY;
+
 # dialect: snowflake
 ARRAY_APPEND([1, 2, 3], 4);
 ARRAY;
@@ -1808,6 +2165,10 @@ ARRAY;
 ARRAY_REMOVE([1, 2, 3], 2);
 ARRAY;
 
+# dialect: snowflake
+ARRAYS_ZIP([1, 2], [3, 4]);
+ARRAY;
+
 # dialect: snowflake
 ASIN(tbl.double_col);
 DOUBLE;
@@ -1832,6 +2193,14 @@ DOUBLE;
 CBRT(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+CBRT(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+CBRT(tbl.int_col);
+DOUBLE;
+
 # dialect: snowflake
 COVAR_POP(tbl.double_col, tbl.double_col);
 DOUBLE;
@@ -1893,7 +2262,15 @@ BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=');
 VARCHAR;
 
 # dialect: snowflake
-BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', '+/=');
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE(tbl.bin_col);
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE('Hello World');
 VARCHAR;
 
 # dialect: snowflake
@@ -1901,7 +2278,7 @@ BASE64_ENCODE('Hello World', 76);
 VARCHAR;
 
 # dialect: snowflake
-BASE64_ENCODE('Hello World', 76, 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BASE64_ENCODE('Hello World', 76, '+/=');
 VARCHAR;
 
 # dialect: snowflake
@@ -2557,15 +2934,143 @@ EQUAL_NULL(1, 2);
 BOOLEAN;
 
 # dialect: snowflake
-EXTRACT(YEAR, CAST('2024-05-09' AS DATE));
+EXTRACT(YEAR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
 INT;
 
 # dialect: snowflake
-EXTRACT(MONTH FROM CAST('2024-05-09 08:50:57' AS TIMESTAMP));
+EXTRACT(QUARTER FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
 INT;
 
 # dialect: snowflake
-EXTRACT(MINUTE, CAST('08:50:57' AS TIME));
+EXTRACT(MONTH FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAY FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFMONTH FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFYEAR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEK FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEKISO FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(HOUR FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(MINUTE FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(SECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+INT;
+
+# dialect: snowflake
+EXTRACT(NANOSECOND FROM CAST('2026-01-06 11:45:00.123456789' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_SECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_MILLISECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_MICROSECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(EPOCH_NANOSECOND FROM CAST('2026-01-06 11:45:00' AS TIMESTAMP_NTZ));
+BIGINT;
+
+# dialect: snowflake
+EXTRACT(YEAR FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(QUARTER FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(MONTH FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(WEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAY FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFMONTH FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFWEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(DAYOFYEAR FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEK FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(YEAROFWEEKISO FROM CAST('2026-01-06' AS DATE));
+INT;
+
+# dialect: snowflake
+EXTRACT(HOUR FROM CAST('11:45:00.123456789' AS TIME));
+INT;
+
+# dialect: snowflake
+EXTRACT(MINUTE FROM CAST('11:45:00.123456789' AS TIME));
+INT;
+
+# dialect: snowflake
+EXTRACT(SECOND FROM CAST('11:45:00.123456789' AS TIME));
 INT;
 
 # dialect: snowflake
@@ -2964,14 +3469,6 @@ INT;
 LEN(tbl.bin_col);
 INT;
 
-# dialect: snowflake
-LENGTH(tbl.str_col);
-INT;
-
-# dialect: snowflake
-LENGTH(tbl.bin_col);
-INT;
-
 # dialect: snowflake
 LOCALTIMESTAMP;
 TIMESTAMPLTZ;
@@ -4948,6 +5445,38 @@ BINARY;
 TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM', HEX_DECODE_BINARY('ff'));
 BINARY;
 
+# dialect: snowflake
+SEQ1();
+INT;
+
+# dialect: snowflake
+SEQ1(1);
+INT;
+
+# dialect: snowflake
+SEQ2();
+INT;
+
+# dialect: snowflake
+SEQ2(1);
+INT;
+
+# dialect: snowflake
+SEQ4();
+INT;
+
+# dialect: snowflake
+SEQ4(1);
+INT;
+
+# dialect: snowflake
+SEQ8();
+BIGINT;
+
+# dialect: snowflake
+SEQ8(1);
+BIGINT;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
@@ -4960,14 +5489,490 @@ TIMESTAMPTZ;
 RADIANS(90);
 INT;
 
+# dialect: tsql
+SIN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+SIN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+COS(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+COS(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+TAN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+TAN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+COT(tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+COT(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.int_col, tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.int_col, tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.float_col, tbl.int_col);
+FLOAT;
+
+# dialect: tsql
+ATN2(tbl.float_col, tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ASIN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ASIN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ACOS(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ACOS(tbl.float_col);
+FLOAT;
+
+# dialect: tsql 
+ATAN(tbl.int_col);
+FLOAT;
+
+# dialect: tsql 
+ATAN(tbl.float_col);
+FLOAT;
+
+# dialect: tsql
+CURRENT_TIMEZONE();
+NVARCHAR;
+
+# dialect: tsql
+SOUNDEX(tbl.str_col);
+VARCHAR;
+
+# dialect: tsql
+STUFF(tbl.str_col, tbl.int_col, tbl.int_col, tbl.str_col);
+VARCHAR;
+
 --------------------------------------
 -- MySQL
 --------------------------------------
 
+# dialect: mysql
+DEGREES(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql
+DEGREES(tbl.int_col);
+DOUBLE;
+
 # dialect: mysql
 LOCALTIME;
 DATETIME;
 
 # dialect: mysql
 ELT(1, 'a', 'b');
-VARCHAR;
\ No newline at end of file
+VARCHAR;
+
+# dialect: mysql
+DAYOFWEEK(tbl.date_col);
+INT;
+
+# dialect: mysql
+DAYOFMONTH(tbl.date_col);
+INT;
+
+# dialect: mysql
+DAYOFYEAR(tbl.date_col);
+INT;
+
+# dialect: mysql
+MONTH(tbl.date_col);
+INT;
+
+# dialect: mysql
+WEEK(tbl.date_col);
+INT;
+
+# dialect: mysql
+WEEK(tbl.date_col, int_col);
+INT;
+
+# dialect: mysql
+QUARTER(tbl.date_col);
+INT;
+
+# dialect: mysql
+HOUR(tbl.time_col);
+INT;
+
+# dialect: mysql
+SECOND(tbl.time_col);
+INT;
+
+# dialect: mysql
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ACOS(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+--------------------------------------
+-- DuckDB
+--------------------------------------
+
+# dialect: duckdb
+SHA1(tbl.str_col);
+VARCHAR;
+
+# dialect: duckdb
+SHA256(tbl.str_col);
+VARCHAR;
+
+# dialect: duckdb 
+GET_BIT(tbl.str_col, tbl.int_col);
+INT;
+
+# dialect: duckdb
+FACTORIAL(tbl.int_col);
+HUGEINT;
+
+# dialect: duckdb
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOS(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOSH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOSH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ASINH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ASINH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATANH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+TANH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+TANH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+COSH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+COSH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+SINH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+SINH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ISINF(tbl.float_col);
+BOOLEAN;
+
+# dialect: duckdb
+RANDOM();
+DOUBLE;
+
+# dialect: duckdb
+QUARTER(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.timestamp_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.interval_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.timestamp_tz_col);
+BIGINT;
+
+# dialect: duckdb
+MINUTE(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb 
+MONTH(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb 
+DAYOFWEEK(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb 
+DAYOFYEAR(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+EPOCH(tbl.interval_col);
+DOUBLE;
+
+# dialect: duckdb
+DAYOFMONTH(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+DAY(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+HOUR(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+SECOND(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+TO_DAYS(tbl.int_col);
+INTERVAL;
+
+# dialect: duckdb
+BIT_LENGTH(tbl.str_col);
+BIGINT;
+
+# dialect: duckdb
+MAKE_TIME(tbl.bigint_col, tbl.bigint_col, tbl.double_col);
+TIME;
+
+# dialect: duckdb
+LENGTH(tbl.str_col);
+BIGINT;
+
+--------------------------------------
+-- Presto / Trino
+--------------------------------------
+
+# dialect: presto, trino
+MD5(tbl.bin_col);
+VARBINARY;
+
+# dialect: presto, trino
+LEVENSHTEIN_DISTANCE(tbl.str_col, tbl.str_col);
+BIGINT;
+
+# dialect: presto, trino
+LENGTH(tbl.str_col);
+BIGINT;
+
+# dialect: presto, trino
+POSITION(tbl.str_col IN tbl.str_col);
+BIGINT;
+
+# dialect: presto, trino
+STRPOS(tbl.str_col, tbl.str_col);
+BIGINT;
+
+# dialect: presto, trino
+BITWISE_AND(tbl.bigint_col, tbl.bigint_col);
+BIGINT;
+
+# dialect: presto, trino
+BITWISE_NOT(tbl.bigint_col);
+BIGINT;
+
+# dialect: presto, trino
+BITWISE_OR(tbl.bigint_col, tbl.bigint_col);
+BIGINT;
+
+# dialect: presto, trino
+BITWISE_XOR(tbl.bigint_col, tbl.bigint_col);
+BIGINT;
+
+# dialect: presto, trino
+WIDTH_BUCKET(tbl.double_col, tbl.array_col);
+BIGINT;
\ No newline at end of file
